<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://appvidlab.com
 * @since      1.0.0
 *
 * @package    Tvdww
 * @subpackage Tvdww/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Tvdww
 * @subpackage Tvdww/admin
 * @author     VidLab <support@appvidlab.com>
 */
class Tvdww_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	private $apiEndpoint;

	private $itemId;

	private $siteDomain;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->apiEndpoint = 'https://ngx64brp4edytxj3qwgpw2iv6y0ynqoo.lambda-url.us-east-2.on.aws/api/sales/vidlab-verify';
		$this->itemId = 158;
		$this->siteDomain = parse_url( get_site_url(), PHP_URL_HOST );

	}

	/**
	 * Sub menu
	 */
	public function tvdww_submenu()
	{
		add_submenu_page(
			'options-general.php',
			__( 'TikTok Video Downloader Without Watermark', 'tvdww' ),
			__( 'TikTok Video Downloader Without Watermark', 'tvdww' ),
			'manage_options',
			'tvdww-options',
			[$this, 'tvdww_option_page']
		);
	}

	/**
	 * Option Page
	 */
	public function tvdww_option_page()
	{
		if ( ! current_user_can( 'manage_options' ) ) return;

		$pC = get_option('tvdwwlicensekey');
		$successMsg = array('class' => 'success', 'msg' =>  __('Thank you for purchasing TikTok Video Downloader Without Watermark', 'tvdww'));
		$errorMsg = array('class' => 'error', 'msg' =>  __('Invalid purchase code or the purchase code already used in another site', 'tvdww'));
		$flashMsg = null;

		if (isset($_POST) && $_POST['tvdwwlicensekey']) {
			check_admin_referer( 'nonce-tvdwwlicensekey' );
			$isValidPc = $this->tvdww_check_pc(trim($_POST['tvdwwlicensekey']));
			if ($isValidPc) {
				if ($pC) {
					update_option('tvdwwlicensekey', esc_attr(trim($_POST['tvdwwlicensekey'])));
				} else {
					add_option('tvdwwlicensekey', esc_attr(trim($_POST['tvdwwlicensekey'])));
				}
				$pC = get_option('tvdwwlicensekey');
				$flashMsg = $successMsg;
			} else {
				$flashMsg = $errorMsg;
			}
		}

		$theme = plugin_dir_path( __DIR__ ).'admin/partials/tvdww-admin-display.php';
		include_once $theme;
	}

	/**
	 * Check License
	 *
	 * @param      string  $pC     The purchase code
	 *
	 * @return     bool    license status
	 */
	public function tvdww_check_pc($pC = null)
	{
		if (!$pC) {
			$pC = get_option('tvdwwlicensekey');
		}

		$pC = trim($pC);

		$query = [
			'code' => $pC,
			'itemId' => $this->itemId,
			'domain' => $this->siteDomain
		];
		$query = http_build_query($query);

		// wp_safe_remote_get / wp_remote_get
		$req = wp_safe_remote_get(
			$this->apiEndpoint.'?'.$query,
			array(
				'timeout'     => 60,
				'headers'     => array(
					'Content-Type'	=> 'application/json'
				),
			)
		);

		if ( is_wp_error( $req ) ) return false;
		if (200 !== wp_remote_retrieve_response_code( $req )) return false;

		return true;
	}

	/**
	 * Check if url is valid
	 */
	public function tvdww_check_url() {
    if ( !wp_verify_nonce($_POST['nonce'], 'tvdww_ajax_nonce') ) { 
    	status_header(403);
			die('Permission Denied.'); 
    }
    try {
    	$time = time();
			$cookies = tempnam('/tmp',"cookie_$time.txt");

			$url = sanitize_text_field($_POST['tikTokVideoUrl']);

			$host = parse_url($url, PHP_URL_HOST);
			$validTiktokHost = strpos($host, 'tiktok.com');
			$validDouyinHost = strpos($host, 'douyin.com');
			if (!$validTiktokHost && !$validDouyinHost) {
	    	status_header(422);
				die('Invalid URL.'); 
			}

			$ch = curl_init();

			curl_setopt($ch, CURLOPT_URL, $url);
			curl_setopt($ch, CURLOPT_COOKIEJAR, $cookies); 
			curl_setopt($ch, CURLOPT_COOKIEFILE, $cookies);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
			curl_setopt($ch, CURLOPT_HTTPHEADER, [
		    'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
		    'Accept-Language: en-US,en;q=0.5',
				'Accept-Encoding: gzip, deflate, br',
				'Connection: keep-alive',
				'Upgrade-Insecure-Requests: 1',
				'Sec-Fetch-Dest: document',
				'Sec-Fetch-Mode: navigate',
				'Sec-Fetch-Site: none',
				'Sec-Fetch-User: ?1',
				'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 13_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/115.0.0.0 Safari/537.36'
			]);
			curl_exec($ch);
			$finalUrl = curl_getinfo($ch, CURLINFO_EFFECTIVE_URL);
			curl_close($ch);

			$path = parse_url($finalUrl, PHP_URL_PATH);
			$videoId = explode('/', $path);
			$videoId = $videoId[count($videoId) - 1];
			if (!is_numeric($videoId)) {
	    	status_header(422);
				die('Invalid URL.'); 
			}
			echo $this->tvdww_get_download_url(trim($videoId));
			wp_die();
    } catch(Exception $e) {
    	status_header(500);
    	die('Failed');
    }
	}

	/**
	 * GET TikTok video url to be downloaded
	 *
	 * @param      integer  $videoId  The video identifier
	 *
	 * @return     string  Download URL
	 */
	public function tvdww_get_download_url($videoId) {
    try {
    	$time = time();
			$cookies = tempnam('/tmp',"cookie_$time.txt");

			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, "https://www.tikwm.com/video/media/play/$videoId.mp4");
			curl_setopt($ch, CURLOPT_COOKIEJAR, $cookies); 
			curl_setopt($ch, CURLOPT_COOKIEFILE, $cookies);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
			curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
			curl_setopt($ch, CURLOPT_HTTPHEADER, [
		    'Accept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
		    'Accept-Language: en-US,en;q=0.5',
				'Accept-Encoding: gzip, deflate, br',
				'Connection: keep-alive',
				'Upgrade-Insecure-Requests: 1',
				'Sec-Fetch-Dest: document',
				'Sec-Fetch-Mode: navigate',
				'Sec-Fetch-Site: none',
				'Sec-Fetch-User: ?1',
				'User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 13_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/115.0.0.0 Safari/537.36'
			]);
			curl_exec($ch);
			$finalUrl = curl_getinfo($ch, CURLINFO_EFFECTIVE_URL);
			curl_close($ch);

			return $finalUrl;
    } catch(Exception $e) {
    	throw $e;
    }
	}

}
